@@ -102,12 +102,11 @@ def reencode(
 
         if fps:
             cmd_filter += 'fps=fps={}'.format(fps)
-
         if sar:
             if len(cmd_filter) > 0:
                 cmd_filter += ','
 
-            cmd_filter += 'setsar={}'.format(sar)
+            cmd_filter += 'setsar={}'.format(sar) 
 
         cmd += ' -filter:v ' + cmd_filter
 
@@ -115,6 +114,15 @@ def reencode(
 
     return path.exists(path_out)
 
+def ts_to_mp4(
+    path_in: str,
+    path_out: str,
+    debug: bool = False
+) -> bool:
+    sh.sh('ffmpeg -y -i {} -acodec copy -vcodec copy {}'.format(path_in, path_out), debug=debug)
+
+    return path.exists(path_out)
+
 def modify_audio(
     path_in: str,
     path_out: str,
